@@ -1,5 +1,5 @@
 # nocov start
-utils::globalVariables(c(".", "%>%", ":=", "%like%", "%chin%"))
+utils::globalVariables(c(".", "%>%", ":=", "%like%", "%chin%", "set"))
 
 .onLoad = function(lib, pkg) {
   requireNamespace("sf")
@@ -17,7 +17,7 @@ utils::globalVariables(c(".", "%>%", ":=", "%like%", "%chin%"))
 
 
 
-#' @importFrom data.table := %between% fifelse %chin%
+#' @importFrom data.table := %between% fifelse %chin% set
 #' @importFrom methods is signature
 NULL
 
@@ -27,10 +27,9 @@ NULL
 if(getRversion() >= "2.15.1") utils::globalVariables(
   c('is', 'duration', 'fromId', 'toId', 'option', 'option', '.SD', 'geometry',
     'route', 'temp_duration', 'temp_route', 'route', 'temp_sign', '.I',
-    'segment_duration', 'total_duration', 'wait'))
+    'segment_duration', 'total_duration', 'wait', 'release_date'))
 
 
 
 
 # nocov end
-
