@@ -8,6 +8,7 @@ path <- system.file("extdata/poa", package = "r5r")
 test_that("setup_r5 - expected behavior", {
 
   testthat::expect_message( setup_r5(data_path = path, verbose = F) )
+  testthat::expect_message( setup_r5(data_path = path, verbose = T) )
 
   # remove files GTFS
   #  file.rename(file.path(path, "poa.zip"), file.path(path, "poa.x"))
@@ -27,15 +28,16 @@ test_that("setup_r5 - expected errors", {
 
   testthat::expect_error( setup_r5(data_path = NULL) )
   testthat::expect_error( setup_r5(data_path = 'a') )
+  testthat::expect_error(setup_r5(verbose = 'a'))
 
 
   # No OSM data
   testthat::expect_error( setup_r5(data_path = file.path(.libPaths()[1]) ) )
 
-  # remove existing network.dat
-    file.rename(file.path(path, "network.dat"), file.path(path, "network2.x"))
-    testthat::expect_error( setup_r5(data_path = path, version = "0") )
-    testthat::expect_error( setup_r5(data_path = path, verbose ='a') )
-    file.rename(file.path(path, "network2.x"), file.path(path, "network.dat"))
+  # # remove existing network.dat
+  #   file.rename(file.path(path, "network.dat"), file.path(path, "network2.x"))
+  #   testthat::expect_error( setup_r5(data_path = path, version = "0") )
+  #   testthat::expect_error( setup_r5(data_path = path, verbose ='a') )
+  #   file.rename(file.path(path, "network2.x"), file.path(path, "network.dat"))
 
   })
